# DeployHub CLI
The dh script interacts with the DeployHub REST APIs to perform a deployment of an application to an environment and update an application version with the component version including attributes.

See [CLI Documentation](doc/dh.md) and [Python API Documentation](doc/deployhub.md)
